@@ -100,6 +100,17 @@ obj_rtf_border <- function(tbl,
     stop("border_color_top can not be NULL if border_color_first is used")
   }
 
+  if(! is.null(attr(tbl, "page")$border_color_first)){
+    border_color_first = ""
+    border_color_top = ""
+  }
+
+  if(! is.null(attr(tbl, "page")$border_color_last)){
+    border_color_last = ""
+    border_color_bottom = ""
+  }
+
+
   # Transfer vector to matrix by row
   n_row <- nrow(tbl)
   n_col <- ncol(tbl)
@@ -111,6 +122,11 @@ obj_rtf_border <- function(tbl,
     }
 
     if ((is.null(dim(x))) & (!is.null(x))) {
+
+      if(! length(x) %in% c(1, n_col, n_col * n_row)){
+        warning("The input is not a single value, with length equal to number of columns or a matrix with same dimension of the table.")
+      }
+
       stopifnot(length(x) %in% c(1, n_col) | all(dim(x) == c(n_row, n_col)))
       x <- matrix(x, nrow = n_row, ncol = n_col, byrow = TRUE)
     }
